Summary:	Library for configuring and customizing font access
Name:		fontconfig
Version:	2.14.2
Release:	4%{?dist}
License:	MIT and Public Domain and UCD
URL:		https://www.freedesktop.org/wiki/Software/fontconfig/
Source0:        https://www.freedesktop.org/software/fontconfig/release/%{name}-%{version}.tar.xz

Patch3000:	fontconfig-disable-network-required-test.patch

BuildRequires:	make autoconf automake libtool gettext
BuildRequires:	libxml2-devel fontpackages-devel
BuildRequires:	freetype-devel >= 2.9.1
BuildRequires:	gperf

Requires:	fonts-filesystem freetype font(:lang=en)
Requires(pre):	freetype >= 2.9.1
Requires(pre):  xml-common
Requires(post):	grep coreutils
Requires(postun): xml-common
# dejavu-fonts providing font(dejavusans) can also provide font(:lang=en)
Suggests:	font(dejavusans)

%description
Fontconfig is a library for configuring and customizing font access. It
contains two essential modules: the configuration module, which builds
an internal configuration from XML files, and the matching module,
which accepts font patterns and returns the nearest matching font.

%package	devel
Summary:	Header files and development docs for fontconfig
Requires:	%{name} = %{version}-%{release}
Requires:	freetype-devel >= 2.9.1
Requires:	pkgconfig gettext

%description	devel
Header files and developer docs for developing programs using fontconfig package.


%prep
%autosetup -p1

%build
# Don't rebuild the docs, but nstall the included ones.
export HASDOCBOOK=no
autoreconf
%configure	--enable-libxml2 --disable-static --docdir=%{_docdir}/%{name} \
                --with-cache-dir=/usr/lib/fontconfig/cache \
                --with-add-fonts=/usr/share/X11/fonts/Type1,/usr/share/X11/fonts/TTF,/usr/local/share/fonts
%make_build


%install
%make_install
find $RPM_BUILD_ROOT -name '*.la' -exec rm -f {} \;

#The file has no symlink, but other conf files have symlink, so create symlink for it
ln -s %{_fontconfig_templatedir}/25-unhint-nonlatin.conf $RPM_BUILD_ROOT%{_sysconfdir}/fonts/conf.d/

%find_lang %{name}
%find_lang %{name}-conf


%check
make check

%post
# Force regeneration of all fontconfig cache files
mkdir -p /usr/lib/fontconfig/cache
[[ -d %{_localstatedir}/cache/fontconfig ]] && rm -rf %{_localstatedir}/cache/fontconfig/* 2> /dev/null || :
HOME=/root %{_bindir}/fc-cache -f

%transfiletriggerin -- /usr/share/fonts /usr/share/X11/fonts/Type1 /usr/share/X11/fonts/TTF /usr/local/share/fonts
HOME=/root %{_bindir}/fc-cache -s

%transfiletriggerpostun -- /usr/share/fonts /usr/share/X11/fonts/Type1 /usr/share/X11/fonts/TTF /usr/local/share/fonts
HOME=/root %{_bindir}/fc-cache -s

%posttrans
if [ -e %{_sysconfdir}/xml/catalog ]; then
  %{_bindir}/xmlcatalog --noout --add system \
                        "urn:fontconfig:fonts.dtd" \
                        "file://%{_datadir}/xml/fontconfig/fonts.dtd" \
                        %{_sysconfdir}/xml/catalog
fi

%postun
if [ $1 == 0 ] && [ -e %{_sysconfdir}/xml/catalog ]; then
  %{_bindir}/xmlcatalog --noout --del "urn:fontconfig:fonts.dtd" %{_sysconfdir}/xml/catalog
fi

%files -f %{name}.lang -f %{name}-conf.lang
%license COPYING
%doc README AUTHORS ChangeLog
%doc %{_sysconfdir}/fonts/conf.d/README
%{_libdir}/libfontconfig.so.*
%{_bindir}/*

%config %{_sysconfdir}/fonts/fonts.conf
%config(noreplace) %{_sysconfdir}/fonts/conf.d/*.conf

%dir %{_datadir}/%{name}/conf.avail
%{_datadir}/%{name}/conf.avail/*.conf

%{_datadir}/xml/fontconfig
%dir /usr/lib/fontconfig/cache
%{_mandir}/man1/*
%{_mandir}/man5/*

%{_docdir}/%{name}/fontconfig-user.html
%{_docdir}/%{name}/fontconfig-user.pdf
%{_docdir}/%{name}/fontconfig-user.txt

%files devel
%{_libdir}/libfontconfig.so
%{_libdir}/pkgconfig/*
%{_includedir}/fontconfig
%{_mandir}/man3/*
%{_datadir}/gettext/its/fontconfig.its
%{_datadir}/gettext/its/fontconfig.loc
%{_docdir}/%{name}/%{name}-devel/
%{_docdir}/%{name}/fontconfig-devel.pdf
%{_docdir}/%{name}/fontconfig-devel.txt

%changelog
* Mon Oct 09 2023 Wang Guodong <gordonwwang@tencent.com> - 2.14.2-4
- Move fonts(:lang=) into Requires

* Wed Sep 13 2023 rockerzhu <rockerzhu@tencent.com> - 2.14.2-3
- Delete patches to provide fonts(:lang=)

* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 2.14.2-2
- Rebuilt for OpenCloudOS Stream 23.09

* Fri Jul 28 2023 Shuo Wang <abushwang@tencent.com> - 2.14.2-1
- update to 2.14.2

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 2.14.0-3
- Rebuilt for OpenCloudOS Stream 23.05

* Fri Mar 31 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 2.14.0-2
- Rebuilt for OpenCloudOS Stream 23

* Tue May 24 2022 rockerzhu <rockerzhu@tencent.com> - 2.14.0-1
- Initial build
